@@ -1,7 +1,10 @@
-#include "cheese-marshal.h"
+
+#ifndef __cheese_marshal_MARSHAL_H__
+#define __cheese_marshal_MARSHAL_H__
 
 #include	<glib-object.h>
 
+G_BEGIN_DECLS
 
 #ifdef G_ENABLE_DEBUG
 #define g_marshal_value_peek_boolean(v)  g_value_get_boolean (v)
@@ -50,14 +53,20 @@
 #endif /* !G_ENABLE_DEBUG */
 
 
-/* VOID:STRING,STRING,STRING,INT (./cheese-marshal.list:1) */
+/* VOID:STRING,STRING,STRING,INT (libcheese/cheese-marshal.list:1) */
+extern void cheese_marshal_VOID__STRING_STRING_STRING_INT (GClosure     *closure,
+                                                           GValue       *return_value,
+                                                           guint         n_param_values,
+                                                           const GValue *param_values,
+                                                           gpointer      invocation_hint,
+                                                           gpointer      marshal_data);
 void
-_cheese_marshal_VOID__STRING_STRING_STRING_INT (GClosure     *closure,
-                                                GValue       *return_value G_GNUC_UNUSED,
-                                                guint         n_param_values,
-                                                const GValue *param_values,
-                                                gpointer      invocation_hint G_GNUC_UNUSED,
-                                                gpointer      marshal_data)
+cheese_marshal_VOID__STRING_STRING_STRING_INT (GClosure     *closure,
+                                               GValue       *return_value G_GNUC_UNUSED,
+                                               guint         n_param_values,
+                                               const GValue *param_values,
+                                               gpointer      invocation_hint G_GNUC_UNUSED,
+                                               gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__STRING_STRING_STRING_INT) (gpointer     data1,
                                                                gpointer     arg_1,
@@ -91,3 +100,7 @@ _cheese_marshal_VOID__STRING_STRING_STRING_INT (GClosure     *closure,
             data2);
 }
 
+G_END_DECLS
+
+#endif /* __cheese_marshal_MARSHAL_H__ */
+
